@@ -4,10 +4,10 @@ from torch.utils.data import DataLoader
 import sys, os
 sys.path.insert(0, os.path.join(
     os.path.dirname(os.path.realpath(__file__)), "../../"))
-from dataloading.dataloading import FeatureExtractorDataset
-from lib.training import test
-from utils.model_editing import drop_layers
-import bin.deep_retrieval_build_db
+from deep_audio_features.dataloading.dataloading import FeatureExtractorDataset
+from deep_audio_features.lib.training import test
+from deep_audio_features.utils.model_editing import drop_layers
+import deep_audio_features.bin.deep_retrieval_build_db
 import config
 import os
 import glob
@@ -25,8 +25,8 @@ def search_deep_database(database_path, query_wav):
         audio_files = pickle.load(f)
         models_folder = pickle.load(f)
 
-    models = bin.deep_retrieval_build_db.load_models(models_folder)
-    f, f_temp, f_names = bin.deep_retrieval_build_db.get_meta_features(query_wav, models)
+    models = deep_audio_features.bin.deep_retrieval_build_db.load_models(models_folder)
+    f, f_temp, f_names = deep_audio_features.bin.deep_retrieval_build_db.get_meta_features(query_wav, models)
     print(all_features_temporal[0])
     d = scipy.spatial.distance.cdist(f.reshape(-1, 1).T, all_features)[0]
     file_sorted = ([x for _, x in sorted(zip(d, audio_files))])
